@@ -1,6 +1,6 @@
 package Config::MVP;
 # ABSTRACT: multivalue-property package-oriented configuration
-$Config::MVP::VERSION = '2.200009';
+$Config::MVP::VERSION = '2.200012';
 use strict;
 use warnings;
 
@@ -28,6 +28,9 @@ use warnings;
 #pod
 #pod This doesn't make sense?  Well, read on.
 #pod
+#pod (You can also read the L<2009 RJBS Advent Calendar
+#pod article|http://advent.rjbs.manxome.org/2009/2009-12-20.html> on Config::MVP!)
+#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod MVP is a mechanism for loading configuration (or other information) for
@@ -219,7 +222,7 @@ Config::MVP - multivalue-property package-oriented configuration
 
 =head1 VERSION
 
-version 2.200009
+version 2.200012
 
 =head1 SYNOPSIS
 
@@ -245,6 +248,9 @@ L<Config::MVP::Assembler|Config::MVP::Assembler>:
 
 This doesn't make sense?  Well, read on.
 
+(You can also read the L<2009 RJBS Advent Calendar
+article|http://advent.rjbs.manxome.org/2009/2009-12-20.html> on Config::MVP!)
+
 =head1 DESCRIPTION
 
 MVP is a mechanism for loading configuration (or other information) for
@@ -426,7 +432,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexandr Ciornii George Hartzell Karen Etheridge Kent Fredric Philippe Bruhat (BooK)
+=for stopwords Alexandr Ciornii George Hartzell Karen Etheridge Kent Fredric Philippe Bruhat (BooK) Sven Kirmess
 
 =over 4
 
@@ -450,11 +456,15 @@ Kent Fredric <kentfredric@gmail.com>
 
 Philippe Bruhat (BooK) <book@cpan.org>
 
+=item *
+
+Sven Kirmess <sven.kirmess@kzone.ch>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
